// Export animation data from Layout to Terragen 2 compatible .chan format
//
// Jan 2010
// (c) Nick Hatzichristos (nixx)
// nixx_vfx@hotmail.com



@version 2.7
@warnings
@script generic
@asyncspawn
@name "TG2 chan Export"

generic
{
    thisScene = Scene();
    sceneItem;
    (sceneItem) = thisScene.getSelect();
    if(!sceneItem) error("Select something !");
    defaultname = "LWmotion(" + sceneItem.name + ")";
    
    reqbegin("TG2 .chan Export v1.1");
        if(sceneItem.isCamera()) FOVmode = ctlpopup("FOV Angle",1,@"Vertical","Horizontal"@);
        rangemode = ctlpopup("Frames",1,@"Preview Range","Render Range"@);
        framecolumn = ctlcheckbox("Include frame number",true);
        chanFile = ctlfilename("Save Chan", defaultname, 30, 0);
        return if !reqpost();
            if(sceneItem.isCamera()) FOVchoice = getvalue(FOVmode);
            rangechoice = getvalue(rangemode);
            framechoice = getvalue(framecolumn);
            fileName = getvalue(chanFile);
    reqend();

    if(rangechoice==1) frameStart = thisScene.previewstart; else frameStart = thisScene.renderstart;
    if(rangechoice==1) frameEnd = thisScene.previewend; else frameEnd = thisScene.renderend;
    fps = thisScene.fps;

    line = "";
    curFrame = "";
    frameCount = 0;
    for(n = frameStart;n <= frameEnd;n++)
    {
        RefreshNow();
        time = n / fps;
        frameCount++;
        xPos[frameCount] = sceneItem.getWorldPosition(time).x;
        yPos[frameCount] = sceneItem.getWorldPosition(time).y;
        zPos[frameCount] = sceneItem.getWorldPosition(time).z*-1;
        xRot[frameCount] = sceneItem.getWorldRotation(time).p*-1;
        yRot[frameCount] = sceneItem.getWorldRotation(time).h*-1;
        zRot[frameCount] = sceneItem.getWorldRotation(time).b;
        xScale[frameCount] = sceneItem.getScaling(time).x;
        yScale[frameCount] = sceneItem.getScaling(time).y;
        zScale[frameCount] = sceneItem.getScaling(time).z;
        if(sceneItem.isCamera()) FOV = sceneItem.fovAngles(time);
        FOVhrz[frameCount] = 0;
        if(sceneItem.isCamera()) FOVhrz[frameCount] = FOV[1] * 180/PI;
        FOVvrt[frameCount] = 0;
        if(sceneItem.isCamera()) FOVvrt[frameCount] = FOV[2] * 180/PI;
    }


    if(strright(fileName,5) != ".chan") fileName = string(fileName, ".chan");
    filedelete(fileName);
    chanout = File(fileName,"w");


    if(FOVchoice==1)
        {
        f = frameStart;
        for(n = 1;n <= frameCount; n++)
            {
            if(framechoice==true) curFrame = string(f, " ");
            f++;
            line = string(curFrame, xPos[n], " ", yPos[n], " ", zPos[n], " ", xRot[n], " ", yRot[n], " ", zRot[n], " ", FOVvrt[n]);
            chanout.writeln(line);
            }
        }
    else
        {
        f = frameStart;
        for(n = 1;n <= frameCount; n++)
            {
            if(framechoice==true) curFrame = string(f, " ");
            f++;
            line = string(curFrame, xPos[n], " ", yPos[n], " ", zPos[n], " ", xRot[n], " ", yRot[n], " ", zRot[n], " ", FOVhrz[n]);
            chanout.writeln(line);
            }
        }

    chanout.close();

    info("Successfully exported  " + frameCount + " frames of motion (range " + frameStart + "..."
                                                        + frameEnd + ") from item \"" + sceneItem.name + "\"");
}



